<?php

/**
 * @file
 *
 * Configuration administrative page.
 */

/**
 * Config form.
 *
 * @param $form
 * @param $form_state
 *
 * @return array
 */
function smsc_send_message_form($form, &$form_state) {

  drupal_add_library('system', 'drupal.ajax');
  drupal_add_library('system', 'jquery.form');

  $drupalSmsc = smsc_get_smsc();
  $config     = $drupalSmsc->getConfig();

  $form['#attached']['css'][] = ['data' => SMSC_PATH . '/assets/css/smsc.css'];

  $form['messages-wrapper'] = [
    '#type'       => 'container',
    '#attributes' => [
      'id'    => 'messages-wrapper',
      'class' => ['messages-wrapper'],
    ],
    '#weight'     => -100,
  ];

  if ($config->hasSettings()) {

    $form['message-form'] = [
      '#type'       => 'container',
      '#attributes' => ['class' => ['message-form']],
    ];

    $form['message-form']['phones'] = [
      '#type'        => 'textfield',
      '#title'       => t('Phones'),
      '#description' => t('Phone number[s]'),
      '#required'    => TRUE,
    ];

    $form['message-form']['message'] = [
      '#type'        => 'textarea',
      '#title'       => t('Message'),
      '#description' => t('Message body'),
      '#required'    => TRUE,
    ];

    $form['message-form']['options'] = [
      '#type'       => 'container',
      '#attributes' => ['class' => ['message-form--options']],
      '#tree'       => TRUE,
    ];

    $form['message-form']['options']['translit'] = [
      '#type'          => 'checkbox',
      '#title'         => t('Transliterate'),
      '#description'   => t('Transliterate message'),
      '#default_value' => $config->get('translit'),
    ];

    $form['message-form']['options']['sender'] = [
      '#type'          => 'select',
      '#title'         => t('Sender ID'),
      '#description'   => t('Choose Sender ID'),
      '#options'       => $drupalSmsc->getSenders(),
      '#size'          => 0,
      '#default_value' => $config->get('sender'),
    ];

    $form['message-form']['submit'] = [
      '#type'  => 'submit',
      '#value' => t('Submit'),
      '#ajax'  => [
        'callback' => 'smsc_ajax_submit_callback',
      ],
    ];

    $form['info'] = [
      '#type'       => 'container',
      '#attributes' => [
        'id'    => 'smsc-info',
        'class' => ['message-form'],
      ],
    ];
  }
  else {
    $settingsLink = url('admin/config/smsc/settings');

    drupal_set_message(t('You need <a href="@url">autorize</a> before send any message!', ['@url' => $settingsLink]), 'warning');

    $form['no-settings'] = [
      '#type'       => 'container',
      '#attributes' => ['class' => ['no-settings']],
    ];

    $form['no-settings']['markup'] = [
      '#markup' => t('<a href="@url">Set up</a> SMSC-account first.', ['@url' => $settingsLink]),
    ];
  }

  return $form;
}

function smsc_ajax_submit_callback($form, &$form_state) {
  $commands[] = ajax_command_html('#messages-wrapper', theme('status_messages'));

  return [
    '#type'     => 'ajax',
    '#commands' => $commands,
  ];
}

/**
 * Submit form.
 *
 * @param $form
 * @param $form_state
 */
function smsc_send_message_form_submit($form, &$form_state) {

  $drupalSmsc = smsc_get_smsc();

  form_state_values_clean($form_state);

  $values = $form_state['values'];

  /**
   * Extract variables from array.
   *
   * @var string $phones
   * @var string $message
   * @var array  $options
   */
  extract($values);

  // Send SMS
  $sms      = $drupalSmsc::sendSms($phones, $message, $options);
  $response = $sms->results();

  if (!isset($response->error)) {
    drupal_set_message(t('Message sent success'));
  }
  else {
    drupal_set_message(t("Message failed! @error", [
      '@error' => $sms->getData()->getStatusCodeMessage(),
    ]), 'error');
  }
}
