<?php

/**
 * @file
 */

namespace Drupal\smsc\Smsc;


use Drupal\smsc\D7Helper\D7Helper;
use Smsc\Services\SmscMessage;
use Smsc\Services\SmscSenders;


/**
 * Class DrupalSmsc.
 */
class DrupalSmsc implements DrupalSmscInterface {

  /**
   * @var null|array
   */
  protected $settings;

  /**
   * @var \Drupal\smsc\D7Helper\D7Helper
   */
  protected $smscConfig;

  /**
   * Constructs a new DrupalSmsc object.
   */
  public function __construct() {
    $this->smscConfig = new D7Helper();
    $this->settings   = DrupalSmscSettings::init();
  }

  /**
   * Get settings.
   *
   * @return null|array
   */
  public function getSettings() {
    return $this->settings;
  }

  /**
   * Get available sender ID's.
   *
   * @return array
   */
  public static function senders() {
    $settings      = DrupalSmscSettings::init();
    $drupalRequest = new DrupalSmscRequest();

    $senders = new SmscSenders($settings);
    $senders->getSenders();
    $senders->send($drupalRequest);

    return $senders->results();
  }

  /**
   * Send SMS.
   *
   * @param string $phones
   * @param string $message
   * @param array  $options
   *
   * @return mixed
   */
  public static function sendSms($phones, $message, $options = []) {
    $settings      = DrupalSmscSettings::init();
    $drupalRequest = new DrupalSmscRequest();

    $sms = new SmscMessage($settings, $phones, $message, $options);
    $sms->send($drupalRequest);

    return $sms;
  }

  /**
   * Get SMSC config.
   *
   * @return \Drupal\smsc\D7Helper\D7Helper
   */
  public function getConfig() {
    return $this->smscConfig;
  }

  /**
   * Get available hosts.
   *
   * @return array
   */
  public function getHosts() {
    $hosts = $this->settings->getApiHosts();

    return array_combine($hosts, $hosts);
  }

  /**
   * Get available sender ID's.
   *
   * @return null|array
   */
  public function getSenders() {
    $senders = &drupal_static(__FUNCTION__);
    $cid     = 'smsc:senders';

    if ($cache = cache_get($cid)) {
      $senders = $cache->data;
    }
    else {

      $senders = [];

      if ($this->settings->valid()) {
        $sendersAvailable = DrupalSmsc::senders();
      }

      if (isset($sendersAvailable) && count($sendersAvailable)) {
        $senders = array_combine($sendersAvailable, $sendersAvailable);
      }

      $senders = ['' => t('Default')] + $senders;

      cache_set($cid, $senders);
    }

    return $senders;
  }
}
